==> man-1.5f.tar.gz: man-1.5f/msgs/mess.cs <==
BAD_CONFIG_FILE
	"nemohu pochopit obsah souboru %s\n"
CONFIG_OPEN_ERROR
	"Varovn: nemohu otevt konfiguran soubor %s\n"
PARSE_ERROR_IN_CONFIG
	"Chyba v analze konfiguranho souboru\n"
INCOMPAT
	"nekompatibiln volby %s a %s\n"
NO_ALTERNATE
	"Promite, ale podpora pro jin systmy nebyla zkompilovna\n"
NO_COMPRESS
	"Man byl konfigurovn pro automatickou kompresi formtovanch strnek,\n\
ale konfiguran soubor nedefinuje COMPRESS.\n"
NO_NAME_FROM_SECTION
	"Kterou manulovou strnku ze sekce %s chcete?\n"
NO_NAME_NO_SECTION
	"Kterou manulovou strnku chcete?\n"
NO_SUCH_ENTRY_IN_SECTION
	"dn zznam o strnce %s c sekci %s manulu\n"
NO_SUCH_ENTRY
	"dn zznam pro %s\n"
PAGER_IS
	"\npouvm %s jako strnkova\n"
SYSTEM_FAILED
	"Nastala chyba pi sputn formtovacho nebo zobrazovacho pkazu.\n\
Pkaz %s skonil a vrtil chybovou hodnotu %d.\n"
VERSION
	"%s, verze %s\n\n"
OUT_OF_MEMORY
	"Nedostatek pamti - nemohu alokovat %d byt\n"
ROFF_CMD_FROM_FILE_ERROR
	"Chyba pi analze *roff pkazu v souboru %s\n"
MANROFFSEQ_ERROR
	"Chybn analza MANROFFSEQ.  Pouiji systmov standard.\n"
ROFF_CMD_FROM_COMMANDLINE_ERROR
	"Chyba pi analze *roff pkazu z pkazov dky.\n"
UNRECOGNIZED_LINE
	"Nerozpoznal jsem dek v konfiguranm souboru (ignoruji jej)\n%s\n"
GETVAL_ERROR
	"man-config.c: vnitn chyba: etzec %s nebyl nalezen\n"
FOUND_MANDIR
	"nael jsem manulov adres %s\n"
FOUND_MAP
	"nalezen manulov cesta je mapovna jako %s --> %s\n"
FOUND_CATDIR
	"odpovdajc adres zformtovanch strnek je %s\n"
LINE_TOO_LONG
	"Pli dlouh dek v konfiguranm souboru\n"
SECTION
	"\nsekce: %s\n"
UNLINKED
	"nespojeno %s\n"
GLOBBING
	"provdm nahrazovn %s\n"
EXPANSION_FAILED
	"Pokus [%s] o formtovn manulov strnky selhal\n"
OPEN_ERROR
	"Nemohu otevt manulovou strnku %s\n"
READ_ERROR
	"Chyba pi ten manulov strnky %s\n"
FOUND_EQN
	"nalezen pkaz pro eqn(1)\n"
FOUND_GRAP
	"nalezen pkaz pro grap(1)\n"
FOUND_PIC
	"nalezen pkaz pro pic(1)\n"
FOUND_TBL
	"nalezen pkaz pro tbl(1)\n"
FOUND_VGRIND
	"nalezen pkaz pro vgrind(1)\n"
FOUND_REFER
	"nalezen pkaz pro refer(1)\n"
ROFF_FROM_COMMAND_LINE
	"analyzuji pkazy z pkazov dky\n"
ROFF_FROM_FILE
	"analyzuji pkazy ze souboru %s\n"
ROFF_FROM_ENV
	"analyzuji pkazy z prosted\n"
USING_DEFAULT
	"pouvm standardn voln preprocesoru\n"
PLEASE_WAIT
	"Formtuji strnku, prosm pokejte...\n"
CHANGED_MODE
	"zmnn md z %s na %o\n"
CAT_OPEN_ERROR
	"Nemohu otevt %s pro zpis.\n"
PROPOSED_CATFILE
	"bude-li teba zkusm zapisovat do %s\n"
IS_NEWER_RESULT
	"nvratov hodnota z is_newer() = %d\n"
TRYING_SECTION
	"zkoum sekci %s\n"
SEARCHING
	"\nhledm v %s\n"
ALREADY_IN_MANPATH
	"ale %s u je v manulov cest\n"
CANNOT_STAT
	"Varovn: nemohu nalzt soubor %s!\n"
IS_NO_DIR
	"Varovn: %s nen adres!\n"
ADDING_TO_MANPATH
	"pidvm %s do manulov cesty\n"
PATH_DIR
	"\nadres cesty %s "
IS_IN_CONFIG
	"je v konfiguranm souboru\n"
IS_NOT_IN_CONFIG
	"nen v konfiguranm souboru\n"
MAN_NEARBY
	"ale pobl je manulov adres\n"
NO_MAN_NEARBY
	"a pobl jsem nenalezl dn manulov adres\n"
ADDING_MANDIRS
	"\npidvm povinn manulov adres\n\n"
CATNAME_IS
	"cat_name v convert_to_cat () je: %s\n"
NO_EXEC
	"\nnespoutm pkaz:\n  %s\n"
USAGE1
	"pouit: %s [-adfhktwW] [sekce] [-M cesta] [-P strnkova] [-S seznam]\n\t"
USAGE2
	"[-m systm] "
USAGE3
	"[-p etzec] jmno ...\n\n"
USAGE4
	"  a : najdi vechny odpovdajc strnky\n\
  c : nepouvej ji zformtovanou strnku\n\
  d : tiskni ladc informace\n\
  D : jako -d, ale zobraz tak manulovou strnku\n\
  f : tot jako whatis(1)\n\
  h : vytiskni tuto pomocnou zprvu\n\
  k : tot jako apropos(1)\n\
  K : hledej etzec ve vech strnkch\n"
USAGE5
	"  t : ke zformtovn pouij program troff\n"
USAGE6
	"\
  w : vytiskni umstn manulovch strnek, kter by byly zobrazeny\n\
      (nen-li uvedeno dn jmno, zobraz prohledvan adrese)\n\
  W : jako -w, ale zobraz pouze jmna soubor;\n\n\
  C soubor     : pouij `soubor' jako konfiguran soubor\n\
  M cesta      : nastav manulov cesty na `cesta'\n\
  P strnkova : pouij program `strnkova' k zobrazen strnek\n\
  S seznam     : rkou oddlen seznam manulovch sekc\n"
USAGE7
	"  m systm : hledej manulov strnky jinho systmu\n"
USAGE8
	"  p etzec : etzec uruje preprocesor, kter bude sputn\n\
               e - [n]eqn(1)   p - pic(1)    t - tbl(1)\n\
               g - grap(1)     r - refer(1)  v - vgrind(1)\n"
USER_CANNOT_OPEN_CAT
	"a skuten uivatel tak neme otevt ji zformtovanou strnku\n"
USER_CAN_OPEN_CAT
	"ale skuten uivatel me otevt ji zformtovanou strnku\n"
CANNOT_FORK
	"nemohu vytvoit dal proces pro _%s_\n"
WAIT_FAILED
	"chyba pi ekn na potomka _%s_\n"
GOT_WRONG_PID
	"velmi podivn ..., dostal jsem patn PID pi ekn na potomka\n"
CHILD_TERMINATED_ABNORMALLY
	"fatl chyba: pkaz _%s_ byl abnormln ukonen\n"
IDENTICAL
	"Manulov strnka %s je shodn s %s\n"
MAN_FOUND
	"Nalezen() manulov() strnky:\n"
NO_TROFF
	"chyba: pkaz TROFF nebyl specifikovn v %s\n"
NO_CAT_FOR_NONSTD_LL
	"dn zformtovan strnka nebyla uloena (nestandardn dlka dku)\n"

==> man-1.6f.tar.gz: man-1.6f/msgs/mess.cs <==
BAD_CONFIG_FILE
	"nemohu pochopit obsah souboru %s\n"
CONFIG_OPEN_ERROR
	"Varovn: nemohu otevt konfiguran soubor %s\n"
PARSE_ERROR_IN_CONFIG
	"Chyba v analze konfiguranho souboru\n"
INCOMPAT
	"nekompatibiln volby %s a %s\n"
NO_ALTERNATE
	"Promite, ale podpora pro jin systmy nebyla zkompilovna\n"
NO_COMPRESS
	"Man byl konfigurovn pro automatickou kompresi formtovanch strnek,\n\
ale konfiguran soubor nedefinuje COMPRESS.\n"
NO_NAME_FROM_SECTION
	"Kterou manulovou strnku ze sekce %s chcete?\n"
NO_NAME_NO_SECTION
	"Kterou manulovou strnku chcete?\n"
NO_SUCH_ENTRY_IN_SECTION
	"dn zznam o strnce %s v sekci %s manulu\n"
NO_SUCH_ENTRY
	"dn zznam pro %s\n"
PAGER_IS
	"\npouvm %s jako strnkova\n"
SYSTEM_FAILED
	"Nastala chyba pi sputn formtovacho nebo zobrazovacho pkazu.\n\
Pkaz %s skonil a vrtil chybovou hodnotu %d.\n"
VERSION
	"%s, verze %s\n\n"
OUT_OF_MEMORY
	"Nedostatek pamti - nemohu alokovat %d byt\n"
ROFF_CMD_FROM_FILE_ERROR
	"Chyba pi analze *roff pkazu v souboru %s\n"
MANROFFSEQ_ERROR
	"Chybn analza MANROFFSEQ.  Pouiji systmov standard.\n"
ROFF_CMD_FROM_COMMANDLINE_ERROR
	"Chyba pi analze *roff pkazu z pkazov dky.\n"
UNRECOGNIZED_LINE
	"Nerozpoznal jsem dek v konfiguranm souboru (ignoruji jej)\n%s\n"
GETVAL_ERROR
	"man-config.c: vnitn chyba: etzec %s nebyl nalezen\n"
FOUND_MANDIR
	"nael jsem manulov adres %s\n"
FOUND_MAP
	"nalezen manulov cesta je mapovna jako %s --> %s\n"
FOUND_CATDIR
	"odpovdajc adres zformtovanch strnek je %s\n"
LINE_TOO_LONG
	"Pli dlouh dek v konfiguranm souboru\n"
SECTION
	"\nsekce: %s\n"
UNLINKED
	"nespojeno %s\n"
GLOBBING
	"provdm nahrazovn %s\n"
EXPANSION_FAILED
	"Pokus [%s] o formtovn manulov strnky selhal\n"
OPEN_ERROR
	"Nemohu otevt manulovou strnku %s\n"
READ_ERROR
	"Chyba pi ten manulov strnky %s\n"
FOUND_EQN
	"nalezen pkaz pro eqn(1)\n"
FOUND_GRAP
	"nalezen pkaz pro grap(1)\n"
FOUND_PIC
	"nalezen pkaz pro pic(1)\n"
FOUND_TBL
	"nalezen pkaz pro tbl(1)\n"
FOUND_VGRIND
	"nalezen pkaz pro vgrind(1)\n"
FOUND_REFER
	"nalezen pkaz pro refer(1)\n"
ROFF_FROM_COMMAND_LINE
	"analyzuji pkazy z pkazov dky\n"
ROFF_FROM_FILE
	"analyzuji pkazy ze souboru %s\n"
ROFF_FROM_ENV
	"analyzuji pkazy z prosted\n"
USING_DEFAULT
	"pouvm standardn voln preprocesoru\n"
PLEASE_WAIT
	"Formtuji strnku, prosm pokejte...\n"
CHANGED_MODE
	"zmnn md z %s na %o\n"
CAT_OPEN_ERROR
	"Nemohu otevt %s pro zpis.\n"
PROPOSED_CATFILE
	"bude-li teba zkusm zapisovat do %s\n"
IS_NEWER_RESULT
	"nvratov hodnota z is_newer() = %d\n"
TRYING_SECTION
	"zkoum sekci %s\n"
SEARCHING
	"\nhledm v %s\n"
ALREADY_IN_MANPATH
	"ale %s u je v manulov cest\n"
CANNOT_STAT
	"Varovn: nemohu nalzt soubor %s!\n"
IS_NO_DIR
	"Varovn: %s nen adres!\n"
ADDING_TO_MANPATH
	"pidvm %s do manulov cesty\n"
PATH_DIR
	"\nadres cesty %s "
IS_IN_CONFIG
	"je v konfiguranm souboru\n"
IS_NOT_IN_CONFIG
	"nen v konfiguranm souboru\n"
MAN_NEARBY
	"ale pobl je manulov adres\n"
NO_MAN_NEARBY
	"a pobl jsem nenalezl dn manulov adres\n"
ADDING_MANDIRS
	"\npidvm povinn manulov adres\n\n"
CATNAME_IS
	"cat_name v convert_to_cat () je: %s\n"
NO_EXEC
	"\nnespoutm pkaz:\n  %s\n"
USAGE1
	"pouit: %s [-adfhktwW] [sekce] [-M cesta] [-P strnkova] [-S seznam]\n\t"
USAGE2
	"[-m systm] "
USAGE3
	"[-p etzec] jmno ...\n\n"
USAGE4
	"  a : najdi vechny odpovdajc strnky\n\
  c : nepouvej ji zformtovanou strnku\n\
  d : tiskni ladc informace\n\
  D : jako -d, ale zobraz tak manulovou strnku\n\
  f : tot jako whatis(1)\n\
  h : vytiskni tuto pomocnou zprvu\n\
  k : tot jako apropos(1)\n\
  K : hledej etzec ve vech strnkch\n"
USAGE5
	"  t : ke zformtovn pouij program troff\n"
USAGE6
	"\
  w : vytiskni umstn manulovch strnek, kter by byly zobrazeny\n\
      (nen-li uvedeno dn jmno, zobraz prohledvan adrese)\n\
  W : jako -w, ale zobraz pouze jmna soubor;\n\n\
  C soubor     : pouij `soubor' jako konfiguran soubor\n\
  M cesta      : nastav manulov cesty na `cesta'\n\
  P strnkova : pouij program `strnkova' k zobrazen strnek\n\
  S seznam     : rkou oddlen seznam manulovch sekc\n"
USAGE7
	"  m systm : hledej manulov strnky jinho systmu\n"
USAGE8
	"  p etzec : etzec uruje preprocesor, kter bude sputn\n\
               e - [n]eqn(1)   p - pic(1)    t - tbl(1)\n\
               g - grap(1)     r - refer(1)  v - vgrind(1)\n"
USER_CANNOT_OPEN_CAT
	"a skuten uivatel tak neme otevt ji zformtovanou strnku\n"
USER_CAN_OPEN_CAT
	"ale skuten uivatel me otevt ji zformtovanou strnku\n"
CANNOT_FORK
	"nemohu vytvoit dal proces pro _%s_\n"
WAIT_FAILED
	"chyba pi ekn na potomka _%s_\n"
GOT_WRONG_PID
	"velmi podivn ..., dostal jsem patn PID pi ekn na potomka\n"
CHILD_TERMINATED_ABNORMALLY
	"fatl chyba: pkaz _%s_ byl abnormln ukonen\n"
IDENTICAL
	"Manulov strnka %s je shodn s %s\n"
MAN_FOUND
	"Nalezen() manulov() strnky:\n"
NO_TROFF
	"chyba: pkaz TROFF nebyl specifikovn v %s\n"
NO_CAT_FOR_NONSTD_LL
	"dn zformtovan strnka nebyla uloena (nestandardn dlka dku)\n"
